==> baikal-0.2.6p0.tgz: baikal/README.md <==
# 1. About this package

This package contains a release of Baïkal.
Go to http://baikal-server.com to get more information about this package, and upgrades.

# 2. What is Baïkal ?

Baïkal is an open source lightweight CalDAV and CardDAV server. It's developped
by Jérôme Schneider and based on the excellent [http://code.google.com/p/sabredav/](SabreDAV) project.
Baïkal is distributed under the GPL license. 

To get more info about the GPL license, visit 
http://www.opensource.org/licenses/gpl-license.php.

# 3. Baïkal requirements

Baïkal is based on PHP 5.3.1+, and uses a SQLite3 or MySQL with PHP PDO. For more
information regarding these requirements see the INSTALL.md file in this folder.

# 4. What should you do if you have a problem ?

  1. Read the available documentation carefully

  2. Search the web carefully about Baïkal CalDAV CardDAV

  3. If you have identified a genuine new bug,
     report it at https://github.com/jeromeschneider/Baikal/issues

# 5. How to install / configure Baïkal

Please read INSTALL.md in this folder.

# 6. How to configure my CalDAV / CardDAV client ?

Please read INSTALL.md in this folder.

# 7. How to upgrade my Baïkal server to a new version ?

Please read UPGRADE.md in this folder.

# 8. Troubleshooting

Please read TROUBLESHOOTING.md in this folder.

# 9. Credits

Baïkal is developed by Jérôme Schneider. 
Jérôme Schneider (@jeromeschneider) is admin and lead developer. 
Many thanks to Daniel Aleksandersen (@zcode) for greatly improving the quality of the project page (http://baikal-server.com). Much appreciated, Daniel :) 

-- Jérôme Schneider <mail@jeromeschneider.fr>  Mon, 21 Aug 2012 12:17:00 +0100

==> baikal-0.2.7.tgz: baikal/README.md <==
# 1. About this package

This package contains a release of Baïkal.
Go to http://baikal-server.com to get more information about this package, and upgrades.

# 2. What is Baïkal ?

Baïkal is an open source lightweight CalDAV and CardDAV server. It's developped
by Jérôme Schneider and based on the excellent [SabreDAV](http://code.google.com/p/sabredav/ "SabreDAV") project.
Baïkal is distributed under the GPL license. 

To get more info about the GPL license, visit 
http://www.opensource.org/licenses/gpl-license.php.

# 3. Baïkal requirements

Baïkal is based on PHP 5.3.1+, and uses a SQLite3 or MySQL with PHP PDO. For more
information regarding these requirements see the INSTALL.md file in this folder.

# 4. What should you do if you have a problem ?

  1. Read the available documentation carefully

  2. Search the web carefully about Baïkal CalDAV CardDAV

  3. If you have identified a genuine new bug,
     report it at https://github.com/jeromeschneider/Baikal/issues

# 5. How to install / configure Baïkal

Please read INSTALL.md in this folder.

# 6. How to configure my CalDAV / CardDAV client ?

Please read INSTALL.md in this folder.

# 7. How to upgrade my Baïkal server to a new version ?

Please read UPGRADE.md in this folder.

# 8. Troubleshooting

Please read TROUBLESHOOTING.md in this folder.

# 9. Credits

Baïkal is developed by Jérôme Schneider. 
Jérôme Schneider (@jeromeschneider) is admin and lead developer. 
Many thanks to Daniel Aleksandersen (@zcode) for greatly improving the quality of the project page (http://baikal-server.com). Much appreciated, Daniel :) 

-- Jérôme Schneider <mail@jeromeschneider.fr>  Mon, 21 Aug 2012 12:17:00 +0100
